@@ -2,30 +2,27 @@ summary.gmInstance <- function(object, type='std', ...){
   type <- match.arg(type,c("std","cliques","rip","configurations"))
 
   cat("Nodes :", object$nodes,"\n")
-  isCompiled <- inherits(object, "compgmInstance")
+  isCompiled   <- inherits(object, "compgmInstance")
   isPropagated <- object$propagated
-  if (isCompiled){
-    cat("Status: Compiled\n")
-  } else {
-    cat("Status: Uncompiled\n")
-  }
-
-  
+  if (is.null(isPropagated))
+    isPropagated <- FALSE
+  else
+    isPropagated <- TRUE
+  cat("Compiled:", isCompiled, "Propagated:", isPropagated, "\n")
   
   if (isCompiled){
-    cat("Model is propagated:", isPropagated, "\n") 
     rip <- object$rip
     cl  <- rip$clique
     se  <- rip$separators
     pa  <- rip$pa
     
-    cat("\n")
+    #cat("\n")
     cl2 <- sapply(object$rip$cliques,length)
-    cat("Number of cliques:",
+    cat(" Number of cliques:",
         length(cl2),"\n")
-    cat("Maximal clique size:",
+    cat(" Maximal clique size:",
         max(cl2),"\n")
-    cat("Maximal number of configurations in cliques:",
+    cat(" Maximal number of configurations in cliques:",
         max(unlist(  sapply(object$potlist, "[", "ncells"))), "\n")
     
     if(length(e<-evidence(object))){
